@@ -1,17 +1,17 @@
 LiblineaR<-function(data,labels,type=0,cost=1,epsilon=0.01,bias=TRUE,wi=NULL,cross=0,verbose=FALSE){
 	# <Arg preparation>
-    if(sparse <- inherits(data, "matrix.csr")){
-        # trying to handle the sparse martix case
-        library("SparseM")
-        data = SparseM::t(SparseM::t(data)) # make sure column index are sorted
-        n = data@dimension[1]
-        p = data@dimension[2]
-    } else {
-        # Nb samples
-        n=dim(data)[1]
-        # Nb features
-        p=dim(data)[2]	
-    }
+		if(sparse <- inherits(data, "matrix.csr")){
+				# trying to handle the sparse martix case
+				library("SparseM")
+				data = SparseM::t(SparseM::t(data)) # make sure column index are sorted
+				n = data@dimension[1]
+				p = data@dimension[2]
+		} else {
+				# Nb samples
+				n=dim(data)[1]
+				# Nb features
+				p=dim(data)[2]
+		}
 
 	# Bias
 	if(bias){
@@ -117,10 +117,10 @@ LiblineaR<-function(data,labels,type=0,cost=1,epsilon=0.01,bias=TRUE,wi=NULL,cro
 			as.double(yC),
 			as.integer(n),
 			as.integer(p),
-            # sparse index info
-            as.integer(sparse),
-            as.integer(if(sparse) data@ia else 0),
-            as.integer(if(sparse) data@ja else 0),
+			# sparse index info
+			as.integer(sparse),
+			as.integer(if(sparse) data@ia else 0),
+			as.integer(if(sparse) data@ja else 0),
 
 			as.double(b),
 			as.integer(type),
@@ -130,7 +130,8 @@ LiblineaR<-function(data,labels,type=0,cost=1,epsilon=0.01,bias=TRUE,wi=NULL,cro
 			as.double(Wi),
 			as.integer(WiLabels),
 			as.integer(cross),
-			as.integer(verbose)
+			as.integer(verbose),
+			PACKAGE="LiblineaR"
 			)
 			
 	if(cross==0){
